@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-Net::Blogger - an OOP-ish interface for accessing a weblog via
+Net::Blogger - (DEPRECATED) an OOP-ish interface for accessing a weblog via
 the Blogger XML-RPC API.
 
 =head1 SYNOPSIS
@@ -57,6 +57,10 @@ the Blogger XML-RPC API.
 
 =head1 DESCRIPTION
 
+B<DEPRECATION NOTICE.> This module no longer works and is deprecated. In fact,
+as of this writing (2020-10-19), none of the CPAN modules for Blogger (including
+WebService::Blogger) currently work.
+
 Blogger.pm provides an OOP-ish interface for accessing a weblog
 via the Blogger XML-RPC API.
 
@@ -98,7 +102,7 @@ use strict;
 
 use vars qw ( $AUTOLOAD $LAST_ERROR );
 
-$Net::Blogger::VERSION   = '1.02';
+$Net::Blogger::VERSION   = '1.03';
 
 =head1 PACKAGE METHODS
 
